@@ -6,6 +6,7 @@
 #    Copyright (C) 2000, Brent Neal <brentn@users.sourceforge.net>
 #    Copyright (C) 2001, Leigh Wedding <leigh.wedding@telstra.com>
 #    Copyright (C) 2000-2004, Paul Fenwick <pjf@cpan.org>
+#    Copyright (C) 2014, Chris Good <chris.good@@ozemail.com.au>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -37,10 +38,11 @@ package Finance::Quote::ASX;
 use HTTP::Request::Common;
 use LWP::UserAgent;
 use HTML::TableExtract;
+use Encode;
 
-use vars qw/$ASX_URL $VERSION/;
+use vars qw/$ASX_URL /;
 
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 $ASX_URL = 'http://www.asx.com.au/asx/markets/priceLookup.do?by=asxCodes&asxCodes=';
 
@@ -59,114 +61,120 @@ sub methods {return (australia => \&asx,asx => \&asx)}
 #
 # Maintainer of this section is Paul Fenwick <pjf@cpan.org>
 # 5-May-2001 Updated by Leigh Wedding <leigh.wedding@telstra.com>
+# 24-Feb-2014 Updated by Chris Good <chris.good@@ozemail.com.au>
 
 sub asx {
 	my $quoter = shift;
-	my @stocks = @_;
-	return unless @stocks;
+	my @all_stocks = @_;
+	return unless @all_stocks;
+	my @stocks;
 	my %info;
 
 	my $ua = $quoter->user_agent;
 
-	my $response = $ua->request(GET $ASX_URL.join("%20",@stocks));
-	unless ($response->is_success) {
-		foreach my $stock (@stocks) {
-			$info{$stock,"success"} = 0;
-			$info{$stock,"errormsg"} = "HTTP session failed";
-		}
-		return wantarray() ? %info : \%info;
-	}
+	# ASX webpage only handles up to 10 quote requests at once
 
-	my $te = HTML::TableExtract->new(
-		automap => 0,
-		headers => ["Code", "Last", '\+/-', "Bid", "Offer",
+	while (@stocks = splice(@all_stocks, 0, 10)) {
+		my $response = $ua->request(GET $ASX_URL.join("%20",@stocks));
+		unless ($response->is_success) {
+			foreach my $stock (@stocks, @all_stocks) {
+				$info{$stock,"success"} = 0;
+				$info{$stock,"errormsg"} = "HTTP session failed";
+			}
+			return wantarray() ? %info : \%info;
+		}
+
+		my $te = HTML::TableExtract->new(
+			automap => 0,
+			headers => ["Code", "Last", '\+/-', "Bid", "Offer",
 		            "Open", "High", "Low", "Vol"]);
 
-	$te->parse($response->content);
+		$te->parse(decode('utf-8',$response->content));
 
-	# Extract table contents.
-	my @rows;
-	unless (($te->tables > 0) && ( @rows = $te->rows)) {
-		foreach my $stock (@stocks) {
-			$info{$stock,"success"} = 0;
-			$info{$stock,"errormsg"} = "Failed to parse HTML table.";
-		}
-		return wantarray() ? %info : \%info;
-	}
-
-	# Pack the resulting data into our structure.
-	foreach my $row (@rows) {
-		my $stock = shift(@$row);
-
-		# Skip any blank lines.
-		next unless $stock;
-
-		# Delete spaces and '*' which sometimes appears after the code.
-		# Also delete high bit characters.
-		$stock =~ tr/* \200-\377//d;
-
-		# Delete any whitespace characters
-		$stock =~ s/\s//g;
-
-		$info{$stock,'symbol'} = $stock;
-
-		foreach my $label (qw/last p_change bid offer open
-			      high low volume/) {
-			$info{$stock,$label} = shift(@$row);
-
-			# Again, get rid of nasty high-bit characters.
-			$info{$stock,$label} =~ tr/ \200-\377//d
-				unless ($label eq "name");
-		}
-
-		# If that stock does not exist, it will have a empty
-		# string for all the fields.  The "last" price should
-		# always be defined (even if zero), if we see an empty
-		# string here then we know we've found a bogus stock.
-
-		if ($info{$stock,'last'} eq '') {
-			$info{$stock,'success'} = 0;
-			$info{$stock,'errormsg'}="Stock does not exist on ASX.";
-			next;
-		}
-
-		# Drop commas from volume.
-		$info{$stock,"volume"} =~ tr/,//d;
-
-		# The ASX returns zeros for a number of things if there
-		# has been no trading.  This not only looks silly, but
-		# can break things later.  "correct" zero'd data.
-
-		foreach my $label (qw/open high low/) {
-			if ($info{$stock,$label} == 0) {
-				$info{$stock,$label} = $info{$stock,"last"};
+		# Extract table contents.
+		my @rows;
+		unless (($te->tables > 0) && ( @rows = $te->rows)) {
+			foreach my $stock (@stocks, @all_stocks) {
+				$info{$stock,"success"} = 0;
+				$info{$stock,"errormsg"} = "Failed to parse HTML table.";
 			}
+			return wantarray() ? %info : \%info;
 		}
 
-		# We get a dollar plus/minus change, rather than a
-		# percentage change, so we convert this into a
-		# percentage change, as required.  We should never have
-		# zero opening price, but if we do warn about it.
+		# Pack the resulting data into our structure.
+		foreach my $row (@rows) {
+			my $stock = shift(@$row);
 
-		if ($info{$stock,"open"} == 0) {
-			warn "Zero opening price in p_change calcuation for ".
-			     "stock $stock.  P_change set to zero.";
-			$info{$stock,"p_change"} = 0;
-		} else {
-			$info{$stock,"p_change"} = sprintf("%.2f",
-		                           ($info{$stock,"p_change"}*100)/
-				             $info{$stock,"open"});
+			# Skip any blank lines.
+			next unless $stock;
+
+			# Delete spaces and '*' which sometimes appears after the code.
+			# Also delete high bit characters.
+			$stock =~ tr/* \200-\377//d;
+
+			# Delete any whitespace characters
+			$stock =~ s/\s//g;
+
+			$info{$stock,'symbol'} = $stock;
+
+			foreach my $label (qw/last p_change bid offer open
+				      high low volume/) {
+				$info{$stock,$label} = shift(@$row);
+
+				# Again, get rid of nasty high-bit characters.
+				$info{$stock,$label} =~ tr/ \200-\377//d
+					unless ($label eq "name");
+			}
+
+			# If that stock does not exist, it will have a empty
+			# string for all the fields.  The "last" price should
+			# always be defined (even if zero), if we see an empty
+			# string here then we know we've found a bogus stock.
+
+			if ($info{$stock,'last'} eq '') {
+				$info{$stock,'success'} = 0;
+				$info{$stock,'errormsg'}="Stock does not exist on ASX.";
+				next;
+			}
+
+			# Drop commas from volume.
+			$info{$stock,"volume"} =~ tr/,//d;
+
+			# The ASX returns zeros for a number of things if there
+			# has been no trading.  This not only looks silly, but
+			# can break things later.  "correct" zero'd data.
+
+			foreach my $label (qw/open high low/) {
+				if ($info{$stock,$label} == 0) {
+					$info{$stock,$label} = $info{$stock,"last"};
+				}
+			}
+
+			# We get a dollar plus/minus change, rather than a
+			# percentage change, so we convert this into a
+			# percentage change, as required.  We should never have
+			# zero opening price, but if we do warn about it.
+
+			if ($info{$stock,"open"} == 0) {
+				warn "Zero opening price in p_change calcuation for ".
+				     "stock $stock.  P_change set to zero.";
+				$info{$stock,"p_change"} = 0;
+			} else {
+				$info{$stock,"p_change"} = sprintf("%.2f",
+			                           ($info{$stock,"p_change"}*100)/
+					             $info{$stock,"open"});
+			}
+
+			# Australian indexes all begin with X, so don't tag them
+			# as having currency info.
+
+			$info{$stock, "currency"} = "AUD" unless ($stock =~ /^X/);
+
+			$info{$stock, "method"} = "asx";
+			$info{$stock, "exchange"} = "Australian Stock Exchange";
+			$info{$stock, "price"} = $info{$stock,"last"};
+			$info{$stock, "success"} = 1;
 		}
-
-		# Australian indexes all begin with X, so don't tag them
-		# as having currency info.
-
-		$info{$stock, "currency"} = "AUD" unless ($stock =~ /^X/);
-
-		$info{$stock, "method"} = "asx";
-		$info{$stock, "exchange"} = "Australian Stock Exchange";
-		$info{$stock, "price"} = $info{$stock,"last"};
-		$info{$stock, "success"} = 1;
 	}
 
 	# All done.
