@@ -36,12 +36,12 @@ package Finance::Quote::Cominvest;
 require 5.005;
 
 use strict;
-use vars qw/$COMINVEST_URL $VERSION/;
+use vars qw/$COMINVEST_URL /;
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
 
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 $COMINVEST_URL = ('http://www.cominvest.de/_applications/fonds_application/FondsInfos/FondsInfos_PreiseAktuell_CSVFile.asp?b2b=0&noindex=1&noindex=1&lang=49');
 
