@@ -18,10 +18,10 @@ use strict;
 use warnings;
 
 use base 'Exporter';
-use vars qw/@EXPORT_OK $VERSION $YAHOO_CURRENCY_CONV_URL/;
+use vars qw/@EXPORT_OK  $YAHOO_CURRENCY_CONV_URL/;
 
 @EXPORT_OK = qw( known_currencies fetch_live_currencies );
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 use HTTP::Request::Common;
 use LWP::UserAgent;
