@@ -33,13 +33,13 @@ require 5.004;
 
 use strict;
 
-use vars qw($VERSION $FTPORTFOLIOS_URL $FTPORTFOLIOS_ALL);
+use vars qw( $FTPORTFOLIOS_URL $FTPORTFOLIOS_ALL);
 
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTML::TableExtract;
 
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 # URLs of where to obtain information.
 
