@@ -35,8 +35,8 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301, USA
+#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+#    02111-1307, USA
 #
 
 
@@ -46,7 +46,7 @@ require 5.005;
 use strict;
 use warnings;
 
-# Set DEBUG => 0 for no debug messages, => 1 for first level, => 2 for 2nd level, etc.
+# Set DEBUG => 1 for no debug messages, => 1 for first level, => 2 for 2nd level, etc.
 
 use constant DEBUG => 0;
 
@@ -59,10 +59,10 @@ use HTTP::Cookies;
 use HTML::TokeParser;
 # use Data::Dumper;
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.24'; # VERSION
 
-$FTFUNDS_MAIN_URL   =   "https://markets.ft.com";
-$FTFUNDS_LOOK_LD    =   "https://markets.ft.com/data/funds/tearsheet/summary?s=";
+$FTFUNDS_MAIN_URL   =   "http://funds.ft.com";
+$FTFUNDS_LOOK_LD    =   "http://funds.ft.com/UK/Tearsheet/Summary?s=";
 $FTFUNDS_LOOK_UD    =	"http://funds.ft.com/UnlistedTearsheet/Summary?s=";
 
                         # this will work with ISIN codes only.
@@ -131,7 +131,7 @@ sub ftfunds_fund  {
 
 DEBUG and print "\nTitle  = ",$webdoc->title,"\n";
 DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
-# DEBUG > 1 and print "\nCookie Jar = : \n",Dumper($cj),"\n\n";
+DEBUG > 1 and print "\nCookie Jar = : \n",Dumper($cj),"\n\n";
 
 		$fundquote {$code, "source"} = $FTFUNDS_LOOK_LD.$code;
 
@@ -154,7 +154,7 @@ DEBUG and print "\nTrying unlisted funds for ",$code," : ",$1,"\n";
 
 DEBUG and print "\nTitle  = ",$webdoc->title,"\n";
 DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
-# DEBUG > 1 and print "\nCookie Jar = : \n",Dumper($cj),"\n\n";
+DEBUG > 1 and print "\nCookie Jar = : \n",Dumper($cj),"\n\n";
 
 			$fundquote {$code, "source"} = $FTFUNDS_LOOK_UD.$code;
 		}
@@ -165,7 +165,7 @@ DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
 
         my $name;
 		if ($webdoc->content =~
-        m[<title>(.*) [Ss]ummary - FT.com] )
+        m[<title>(.*) Summary - FT.com] )
         {
             $name = $1 ;
         }
@@ -178,21 +178,13 @@ DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
 		}
 		$fundquote {$code, "name"} = $name;	# set name
 
-# Find price and currency
-		my $currency;
+# Find price
 		my $price;
 		if ($webdoc->content =~
-		m[<span class="mod-ui-data-list__label"[^>]*>Price [(]([A-Z]{3})[)]</span><span class="mod-ui-data-list__value">([\.\,0-9]*)</span>]  )
+		m[<div class="contains wsodModuleContent"><table><tbody><tr><td class="text first">([\.\,0-9]*)</td>]  )
         {
-			$currency = $1;
-			$price    = $2;
+			$price   = $1;
         }
-		if (!defined($currency)) {
-			# serious error, report it and give up
-			$fundquote {$code,"success"} = 0;
-			$fundquote {$code,"errormsg"} = "Error - failed to find a currency";
-			next;
-		}
 		if (!defined($price)) {
 			# serious error, report it and give up
 			$fundquote {$code,"success"} = 0;
@@ -208,10 +200,10 @@ DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
 		my $net;
 		my $pchange;
 		if ($webdoc->content =~
-		m[<span class="mod-ui-data-list__label">Today's Change</span><span class="mod-ui-data-list__value"><span [^>]*><i [^>]*></i>(-?[\.0-9]*) / (-?[\.0-9]*)%</span>] )
+		m[<span class="(pos|neg) color ">([\.0-9]*) / ([\.0-9]*)%</span>] )
         {
-            $net = $1 ;
-            $pchange = $2;
+            $net = $2 ;     # allow for alternates in match string
+            $pchange = $3;
         }
 		if (!defined($net)) {
 			# not a serious error - don't report it ....
@@ -238,7 +230,24 @@ DEBUG and print "\nStatus = ",$webdoc->status_line, "\n";
 			$pchange	  = $1 * 1000 + $2;
 		}
 
+# Find the currency
+		my $currency;
+		if ($webdoc->content =~
+		m[($code):([A-Z]{3})]  )
+        {
+
+			$currency    = $2;
+        }
+
+		if (!defined($currency)) {
+			# serious error, report it and give up
+			$fundquote {$code,"success"} = 0;
+			$fundquote {$code,"errormsg"} = "Error - failed to find a currency";
+			next;
+		}
+
 # deal with GBX pricing of UK unit trusts
+
 		if ($currency eq "GBX")
 		{
 			$currency = "GBP" ;
@@ -338,7 +347,7 @@ facilities to identify the funds of interest. The factsheet display for any give
 fund displays the ISIN along with other useful information.
 
 This module is loaded by default on a Finance::Quote object. It's
-also possible to load it explicitly by placing "ftfunds" in the argument
+also possible to load it explicity by placing "ftfunds" in the argument
 list to Finance::Quote->new().
 
 Information obtained by this module may be covered by funds.ft.com
