@@ -39,9 +39,9 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use HTML::TableExtract;
 
-use vars qw/$PLATINUM_URL $VERSION/;
+use vars qw/$PLATINUM_URL /;
 
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 $PLATINUM_URL = 'http://www.platinum.com.au/Platinum_Trust_Unit_Prices.htm';
 
