@@ -33,9 +33,9 @@ use HTTP::Request::Common;
 use LWP::UserAgent;
 use Finance::Quote::Yahoo::Base qw/yahoo_request base_yahoo_labels/;
 
-use vars qw/$VERSION $YAHOO_AUSTRALIA_URL/;
+use vars qw/ $YAHOO_AUSTRALIA_URL/;
 
-$VERSION = '1.20' ;
+our $VERSION = '1.24'; # VERSION
 
 # URLs of where to obtain information.
 
